@@ -23,6 +23,30 @@ function is_api_endpoint() {
     return false;
 }
 
+// Function to check if current request is to Adminer
+function is_adminer_endpoint() {
+    $script_path = $_SERVER['SCRIPT_FILENAME'];
+    $request_uri = $_SERVER['REQUEST_URI'];
+    $script_name = basename($_SERVER['SCRIPT_NAME']);
+    
+    // Check if the script is adminer.php
+    if ($script_name === 'adminer.php') {
+        return true;
+    }
+    
+    // Check if the request URI is for adminer
+    if (strpos($request_uri, '/adminer.php') !== false) {
+        return true;
+    }
+    
+    // Check if the script path contains adminer.php
+    if (strpos($script_path, 'adminer.php') !== false) {
+        return true;
+    }
+    
+    return false;
+}
+
 // Function to validate CSRF token
 function validate_csrf_token() {
     if ($_SERVER['REQUEST_METHOD'] === 'POST') {
@@ -171,10 +195,10 @@ if (defined('AUTH_USER') && $_SERVER['SCRIPT_FILENAME'] == '/docker/whp/web/inde
     check_page_permission();
 }
 
-// CSRF Protection for all POST requests (except login)
+// CSRF Protection for all POST requests (except login and Adminer)
 if (defined('AUTH_USER') && $_SERVER['REQUEST_METHOD'] === 'POST') {
-    // Skip CSRF check for login form
-    if (!isset($_POST['user']) && !isset($_POST['password'])) {
+    // Skip CSRF check for login form and Adminer
+    if (!isset($_POST['user']) && !isset($_POST['password']) && !is_adminer_endpoint()) {
         if (!validate_csrf_token()) {
             if (is_api_endpoint()) {
                 header('HTTP/1.1 403 Forbidden');
